{% extends "base_error.html" %}

{% block title %}500 - Internal Server Error{% endblock %}

{% block content %}
<h1>500. Damn.</h1>
<h3>“There are two ways to write error-free programs; only the third one works.” - Alan J. Perlis</h3>
<p>OpenSubmit ran into an internal error which cannot be fixed. Please try to use your browsers 'Back' button.</p>
<p>The developers are informed. You can check if your problem <a href="https://github.com/troeger/opensubmit/issues">is already known</a>.</p>
<p>Sorry for any inconvinience!</p>
{% endblock %}
