{% extends "admin/base.html" %}

{% load projecttags %}
{% load bootstrap %}

{% block title %}
    {{ block.super }} - eMail
{% endblock %}

{% block breadcrumbs %}
    <ul>
        <li><a href="{% url 'teacher:index' %}">Home</a></li>
        <li> Write eMail</li>
    </ul>
{% endblock %}

{% block extrastyle %}
<link href="/static/css/admin.css" type="text/css" media="all" rel="stylesheet" />

<style>
#id_subject {
	width: 758px;
}
#id_message {
	height: 400px;
}
</style>

{% endblock %}

{% block content %}
<div class="page-header">
    <h1>eMail - {{ course }}</h1>
</div>

<fieldset class="module grp-module">
<div class="form-row grp-row">
Option 1: <a href="mailto:{{maillist}}">Use your own eMail program</a>.
</div>

</fieldset>
<fieldset class="module grp-module">
<div class="form-row grp-row grp-cells-1">
Option 2: Copy the following list for further processing:
<br/><br/>
{{maillist}}
</div>

</fieldset>
<fieldset class="module grp-module">
<div class="form-row grp-row">
Option 3: Send individual mails with the form below. Supported placeholders are <i>#FIRSTNAME#</i>, <i>#LASTNAME#</i> and <i>#COURSENAME#</i>:
</ul>
<br/><br/>
<form class="form" role="form" action="." method="post">
	{% csrf_token %}
	<table>
	{{ mailform.as_table }}
	<tr><td></td><td><input type="submit" href="." value="Preview"/></td></tr>
	</table>
</form>
</div>
</fieldset>

{% endblock %}
