<!DOCTYPE html>
<html lang="en">

<head>
<title>{% block title %}{% endblock %}</title>
<style type="text/css">
    @import url("{{STATIC_URL}}bootstrap/css/bootstrap.min.css");
</style>
</head>

<body>
    <div class="container">
        <div class="well">
	        {% block content %}{% endblock %}
        </div>
    	{% include "footer.html" %}
	</div>
</body>
</html>
