from .course import Course
from .grading import Grading
from .gradingscheme import GradingScheme
from .testmachine import TestMachine
from .submission import Submission
from .submissionfile import SubmissionFile
from .submissiontestresult import SubmissionTestResult
from .assignment import Assignment
from .userprofile import UserProfile

