{% extends "base.html" %}

{% load projecttags %}

{% block scripts %}
{{ block.super }}
{% endblock %}

{% block style %}
{{ block.super }}
@import url("{{ STATIC_URL }}social-buttons/auth-buttons.css");
{% endblock %}

{% block docready %}
{{ block.super }}
{% endblock %}

{%block navigation_home %}hidden{% endblock %}
{%block navigation_settings %}hidden{% endblock %}
{%block navigation_courses %}hidden{% endblock %}
{%block navigation_logout %}hidden{% endblock %}

{% block content %}
<br/>
<div class="page-header">
    <h1>
        Welcome <br/>
        <small>Assignment Management and Submission System</small>
    </h1>
</div>

{% include "login_buttons.inc" %}

{% endblock %}
