{% extends "admin/base.html" %}

{% load projecttags %}
{% load bootstrap %}

{% block title %}
    {{ block.super }} - eMail
{% endblock %}

{% block breadcrumbs %}
    <ul>
        <li><a href="{% url 'teacher:index' %}">Home</a></li>
        <li><a href="javascript:history.back()">Write eMail</a></li>
        <li>Preview</li>
    </ul>
{% endblock %}

{% block extrastyle %}
<link href="/static/css/admin.css" type="text/css" media="all" rel="stylesheet" />
{% endblock %}

{% block content %}
<div class="page-header">
    <h1>eMail - {{ course }}</h1>
</div>

<p>Example:</p>

<fieldset class="module grp-module">
<div class="form-row grp-row">
	<div class="field-box">
		From:<br/>{{ preview_from }}
	</div>
</div>
<div class="form-row grp-row">
	<div class="field-box">
		Subject:<br/>{{ preview_subject }}
	</div>
</div>
<div class="form-row grp-row">
	<div class="field-box">
		Message:<br/>{{ preview_message|linebreaksbr }}
	</div>
</div>
</fieldset>


<form class="form" role="form" action="." method="post">
	{% csrf_token %}
	<input type="submit" href="." value="Send"></input>

</form>

{% endblock %}
