{% extends "base.html" %}
{% load projecttags %}
{% load bootstrap %}

{% block title %}
    {{ block.super }} - Submission Details
{% endblock %}

{% block content %}
<div class="page-header">
    <h1>Submission Details</h1>
</div>

{% details_table submission %}

{% endblock %}
